@@ -147,6 +147,7 @@ def update_and_restart() -> None:
 
     with contextlib.suppress(ResourceWarning):
         env = os.environ.copy()
+        env["ANKI_LAUNCHER_WANT_TERMINAL"] = "1"
         # fixes a bug where launcher fails to appear if opening it
         # straight after updating
         if "GNOME_TERMINAL_SCREEN" in env:
@@ -156,12 +157,15 @@ def update_and_restart() -> None:
             creationflags = (
                 subprocess.CREATE_NEW_PROCESS_GROUP | subprocess.DETACHED_PROCESS
             )
+        # On Windows 10, changing the handles breaks ANSI display
+        io = None if sys.platform == "win32" else subprocess.DEVNULL
+
         subprocess.Popen(
             [launcher],
             start_new_session=True,
-            stdin=subprocess.DEVNULL,
-            stdout=subprocess.DEVNULL,
-            stderr=subprocess.DEVNULL,
+            stdin=io,
+            stdout=io,
+            stderr=io,
             env=env,
             creationflags=creationflags,
         )
