@@ -11,7 +11,6 @@ use std::time::SystemTime;
 use std::time::UNIX_EPOCH;
 
 use anki_io::copy_file;
-use anki_io::copy_if_newer;
 use anki_io::create_dir_all;
 use anki_io::modified_time;
 use anki_io::read_file;
@@ -47,9 +46,13 @@ struct State {
     uv_lock_path: std::path::PathBuf,
     sync_complete_marker: std::path::PathBuf,
     launcher_trigger_file: std::path::PathBuf,
+    mirror_path: std::path::PathBuf,
     pyproject_modified_by_user: bool,
     previous_version: Option<String>,
     resources_dir: std::path::PathBuf,
+    venv_folder: std::path::PathBuf,
+    /// system Python + PyQt6 library mode
+    system_qt: bool,
 }
 
 #[derive(Debug, Clone)]
@@ -71,6 +74,7 @@ pub enum MainMenuChoice {
     Version(VersionKind),
     ToggleBetas,
     ToggleCache,
+    DownloadMirror,
     Uninstall,
 }
 
@@ -86,9 +90,13 @@ fn main() {
 }
 
 fn run() -> Result<()> {
-    let uv_install_root = dirs::data_local_dir()
-        .context("Unable to determine data_dir")?
-        .join("AnkiProgramFiles");
+    let uv_install_root = if let Ok(custom_root) = std::env::var("ANKI_LAUNCHER_VENV_ROOT") {
+        std::path::PathBuf::from(custom_root)
+    } else {
+        dirs::data_local_dir()
+            .context("Unable to determine data_dir")?
+            .join("AnkiProgramFiles")
+    };
 
     let (exe_dir, resources_dir) = get_exe_and_resources_dirs()?;
 
@@ -108,9 +116,13 @@ fn run() -> Result<()> {
         uv_lock_path: uv_install_root.join("uv.lock"),
         sync_complete_marker: uv_install_root.join(".sync_complete"),
         launcher_trigger_file: uv_install_root.join(".want-launcher"),
+        mirror_path: uv_install_root.join("mirror"),
         pyproject_modified_by_user: false, // calculated later
         previous_version: None,
+        system_qt: (cfg!(unix) && !cfg!(target_os = "macos"))
+            && resources_dir.join("system_qt").exists(),
         resources_dir,
+        venv_folder: uv_install_root.join(".venv"),
     };
 
     // Check for uninstall request from Windows uninstaller
@@ -120,15 +132,11 @@ fn run() -> Result<()> {
         return Ok(());
     }
 
-    // Create install directory and copy project files in
+    // Create install directory
     create_dir_all(&state.uv_install_root)?;
-    copy_if_newer(&state.dist_pyproject_path, &state.user_pyproject_path)?;
-    copy_if_newer(
-        &state.dist_python_version_path,
-        &state.user_python_version_path,
-    )?;
 
-    let launcher_requested = state.launcher_trigger_file.exists();
+    let launcher_requested =
+        state.launcher_trigger_file.exists() || !state.user_pyproject_path.exists();
 
     // Calculate whether user has custom edits that need syncing
     let pyproject_time = file_timestamp_secs(&state.user_pyproject_path);
@@ -158,15 +166,10 @@ fn run() -> Result<()> {
 
     check_versions(&mut state);
 
-    let first_run = !state.uv_install_root.join(".venv").exists();
-    if first_run {
-        handle_version_install_or_update(&state, MainMenuChoice::Latest)?;
-    } else {
-        main_menu_loop(&state)?;
-    }
+    main_menu_loop(&state)?;
 
     // Write marker file to indicate we've completed the sync process
-    write_sync_marker(&state.sync_complete_marker)?;
+    write_sync_marker(&state)?;
 
     #[cfg(target_os = "macos")]
     {
@@ -192,13 +195,15 @@ fn run() -> Result<()> {
     Ok(())
 }
 
-fn extract_aqt_version(
-    uv_path: &std::path::Path,
-    uv_install_root: &std::path::Path,
-) -> Option<String> {
-    let output = Command::new(uv_path)
-        .current_dir(uv_install_root)
-        .env("VIRTUAL_ENV", uv_install_root.join(".venv"))
+fn extract_aqt_version(state: &State) -> Option<String> {
+    // Check if .venv exists first
+    if !state.venv_folder.exists() {
+        return None;
+    }
+
+    let output = uv_command(state)
+        .ok()?
+        .env("VIRTUAL_ENV", &state.venv_folder)
         .args(["pip", "show", "aqt"])
         .output()
         .ok()?;
@@ -223,7 +228,7 @@ fn check_versions(state: &mut State) {
     }
 
     // Determine current version by invoking uv pip show aqt
-    match extract_aqt_version(&state.uv_path, &state.uv_install_root) {
+    match extract_aqt_version(state) {
         Some(version) => {
             state.current_version = Some(version);
         }
@@ -248,12 +253,12 @@ fn handle_version_install_or_update(state: &State, choice: MainMenuChoice) -> Re
     update_pyproject_for_version(choice.clone(), state)?;
 
     // Extract current version before syncing (but don't write to file yet)
-    let previous_version_to_save = extract_aqt_version(&state.uv_path, &state.uv_install_root);
+    let previous_version_to_save = extract_aqt_version(state);
 
     // Remove sync marker before attempting sync
     let _ = remove_file(&state.sync_complete_marker);
 
-    println!("\x1B[1mUpdating Anki...\x1B[0m\n");
+    println!("Updating Anki...\n");
 
     let python_version_trimmed = if state.user_python_version_path.exists() {
         let python_version = read_file(&state.user_python_version_path)?;
@@ -265,24 +270,64 @@ fn handle_version_install_or_update(state: &State, choice: MainMenuChoice) -> Re
     };
 
     // Prepare to sync the venv
-    let mut command = Command::new(&state.uv_path);
-    command.current_dir(&state.uv_install_root);
+    let mut command = uv_command(state)?;
 
-    // remove UV_* environment variables to avoid interference
-    for (key, _) in std::env::vars() {
-        if key.starts_with("UV_") || key == "VIRTUAL_ENV" {
-            command.env_remove(key);
+    if cfg!(target_os = "macos") {
+        // remove CONDA_PREFIX/bin from PATH to avoid conda interference
+        if let Ok(conda_prefix) = std::env::var("CONDA_PREFIX") {
+            if let Ok(current_path) = std::env::var("PATH") {
+                let conda_bin = format!("{conda_prefix}/bin");
+                let filtered_paths: Vec<&str> = current_path
+                    .split(':')
+                    .filter(|&path| path != conda_bin)
+                    .collect();
+                let new_path = filtered_paths.join(":");
+                command.env("PATH", new_path);
+            }
         }
+        // put our fake install_name_tool at the top of the path to override
+        // potential conflicts
+        if let Ok(current_path) = std::env::var("PATH") {
+            let exe_dir = std::env::current_exe()
+                .ok()
+                .and_then(|exe| exe.parent().map(|p| p.to_path_buf()));
+            if let Some(exe_dir) = exe_dir {
+                let new_path = format!("{}:{}", exe_dir.display(), current_path);
+                command.env("PATH", new_path);
+            }
+        }
+    }
+
+    // Create venv with system site packages if system Qt is enabled
+    if state.system_qt {
+        let mut venv_command = uv_command(state)?;
+        venv_command.args([
+            "venv",
+            "--no-managed-python",
+            "--system-site-packages",
+            "--no-config",
+        ]);
+        venv_command.ensure_success()?;
     }
 
     command
         .env("UV_CACHE_DIR", &state.uv_cache_dir)
         .env("UV_PYTHON_INSTALL_DIR", &state.uv_python_install_dir)
-        .args(["sync", "--upgrade", "--managed-python", "--no-config"]);
+        .env(
+            "UV_HTTP_TIMEOUT",
+            std::env::var("UV_HTTP_TIMEOUT").unwrap_or_else(|_| "180".to_string()),
+        );
 
-    // Add python version if .python-version file exists
+    command.args(["sync", "--upgrade", "--no-config"]);
+    if !state.system_qt {
+        command.arg("--managed-python");
+    }
+
+    // Add python version if .python-version file exists (but not for system Qt)
     if let Some(version) = &python_version_trimmed {
-        command.args(["--python", version]);
+        if !state.system_qt {
+            command.args(["--python", version]);
+        }
     }
 
     if state.no_cache_marker.exists() {
@@ -293,7 +338,7 @@ fn handle_version_install_or_update(state: &State, choice: MainMenuChoice) -> Re
         Ok(_) => {
             // Sync succeeded
             if matches!(&choice, MainMenuChoice::Version(VersionKind::PyOxidizer(_))) {
-                inject_helper_addon(&state.uv_install_root)?;
+                inject_helper_addon()?;
             }
 
             // Now that sync succeeded, save the previous version
@@ -357,6 +402,11 @@ fn main_menu_loop(state: &State) -> Result<()> {
                 println!();
                 continue;
             }
+            MainMenuChoice::DownloadMirror => {
+                show_mirror_submenu(state)?;
+                println!();
+                continue;
+            }
             MainMenuChoice::Uninstall => {
                 if handle_uninstall(state)? {
                     std::process::exit(0);
@@ -364,9 +414,7 @@ fn main_menu_loop(state: &State) -> Result<()> {
                 continue;
             }
             choice @ (MainMenuChoice::Latest | MainMenuChoice::Version(_)) => {
-                if handle_version_install_or_update(state, choice.clone()).is_err() {
-                    continue;
-                }
+                handle_version_install_or_update(state, choice.clone())?;
                 break;
             }
         }
@@ -374,12 +422,12 @@ fn main_menu_loop(state: &State) -> Result<()> {
     Ok(())
 }
 
-fn write_sync_marker(sync_complete_marker: &std::path::Path) -> Result<()> {
+fn write_sync_marker(state: &State) -> Result<()> {
     let timestamp = SystemTime::now()
         .duration_since(UNIX_EPOCH)
         .context("Failed to get system time")?
         .as_secs();
-    write_file(sync_complete_marker, timestamp.to_string())?;
+    write_file(&state.sync_complete_marker, timestamp.to_string())?;
     Ok(())
 }
 
@@ -423,8 +471,13 @@ fn get_main_menu_choice(state: &State) -> Result<MainMenuChoice> {
             "6) Cache downloads: {}",
             if cache_enabled { "on" } else { "off" }
         );
+        let mirror_enabled = is_mirror_enabled(state);
+        println!(
+            "7) Download mirror: {}",
+            if mirror_enabled { "on" } else { "off" }
+        );
         println!();
-        println!("7) Uninstall");
+        println!("8) Uninstall");
         print!("> ");
         let _ = stdout().flush();
 
@@ -463,7 +516,8 @@ fn get_main_menu_choice(state: &State) -> Result<MainMenuChoice> {
             }
             "5" => MainMenuChoice::ToggleBetas,
             "6" => MainMenuChoice::ToggleCache,
-            "7" => MainMenuChoice::Uninstall,
+            "7" => MainMenuChoice::DownloadMirror,
+            "8" => MainMenuChoice::Uninstall,
             _ => {
                 println!("Invalid input. Please try again.");
                 continue;
@@ -473,8 +527,6 @@ fn get_main_menu_choice(state: &State) -> Result<MainMenuChoice> {
 }
 
 fn get_version_kind(state: &State) -> Result<Option<VersionKind>> {
-    println!("Please wait...");
-
     let releases = get_releases(state)?;
     let releases_str = releases
         .latest
@@ -631,17 +683,33 @@ fn filter_and_normalize_versions(
 fn fetch_versions(state: &State) -> Result<Vec<String>> {
     let versions_script = state.resources_dir.join("versions.py");
 
-    let mut cmd = Command::new(&state.uv_path);
-    cmd.current_dir(&state.uv_install_root)
-        .args(["run", "--no-project"])
-        .arg(&versions_script);
+    let mut cmd = uv_command(state)?;
+    cmd.args(["run", "--no-project", "--no-config", "--managed-python"])
+        .args(["--with", "pip-system-certs,requests[socks]"]);
 
-    let output = cmd.utf8_output()?;
+    let python_version = read_file(&state.dist_python_version_path)?;
+    let python_version_str =
+        String::from_utf8(python_version).context("Invalid UTF-8 in .python-version")?;
+    let version_trimmed = python_version_str.trim();
+    if !version_trimmed.is_empty() {
+        cmd.args(["--python", version_trimmed]);
+    }
+
+    cmd.arg(&versions_script);
+
+    let output = match cmd.utf8_output() {
+        Ok(output) => output,
+        Err(e) => {
+            print!("Unable to check for Anki versions. Please check your internet connection.\n\n");
+            return Err(e.into());
+        }
+    };
     let versions = serde_json::from_str(&output.stdout).context("Failed to parse versions JSON")?;
     Ok(versions)
 }
 
 fn get_releases(state: &State) -> Result<Releases> {
+    println!("Checking for updates...");
     let include_prereleases = state.prerelease_marker.exists();
     let all_versions = fetch_versions(state)?;
     let all_versions = filter_and_normalize_versions(all_versions, include_prereleases);
@@ -681,7 +749,26 @@ fn apply_version_kind(version_kind: &VersionKind, state: &State) -> Result<()> {
             &format!("anki-release=={version}\",\n  \"anki=={version}\",\n  \"aqt=={version}"),
         ),
     };
-    write_file(&state.user_pyproject_path, &updated_content)?;
+
+    let final_content = if state.system_qt {
+        format!(
+            concat!(
+                "{}\n\n[tool.uv]\n",
+                "override-dependencies = [\n",
+                "  \"pyqt6; sys_platform=='never'\",\n",
+                "  \"pyqt6-qt6; sys_platform=='never'\",\n",
+                "  \"pyqt6-webengine; sys_platform=='never'\",\n",
+                "  \"pyqt6-webengine-qt6; sys_platform=='never'\",\n",
+                "  \"pyqt6_sip; sys_platform=='never'\"\n",
+                "]\n"
+            ),
+            updated_content
+        )
+    } else {
+        updated_content
+    };
+
+    write_file(&state.user_pyproject_path, &final_content)?;
 
     // Update .python-version based on version kind
     match version_kind {
@@ -715,6 +802,9 @@ fn update_pyproject_for_version(menu_choice: MainMenuChoice, state: &State) -> R
         MainMenuChoice::ToggleCache => {
             unreachable!();
         }
+        MainMenuChoice::DownloadMirror => {
+            unreachable!();
+        }
         MainMenuChoice::Uninstall => {
             unreachable!();
         }
@@ -768,7 +858,7 @@ fn parse_version_kind(version: &str) -> Option<VersionKind> {
     }
 }
 
-fn inject_helper_addon(_uv_install_root: &std::path::Path) -> Result<()> {
+fn inject_helper_addon() -> Result<()> {
     let addons21_path = get_anki_addons21_path()?;
 
     if !addons21_path.exists() {
@@ -870,16 +960,40 @@ fn handle_uninstall(state: &State) -> Result<bool> {
     Ok(true)
 }
 
+fn uv_command(state: &State) -> Result<Command> {
+    let mut command = Command::new(&state.uv_path);
+    command.current_dir(&state.uv_install_root);
+
+    // remove UV_* environment variables to avoid interference
+    for (key, _) in std::env::vars() {
+        if key.starts_with("UV_") {
+            command.env_remove(key);
+        }
+    }
+    command
+        .env_remove("VIRTUAL_ENV")
+        .env_remove("SSLKEYLOGFILE");
+
+    // Add mirror environment variable if enabled
+    if let Some((python_mirror, pypi_mirror)) = get_mirror_urls(state)? {
+        command
+            .env("UV_PYTHON_INSTALL_MIRROR", &python_mirror)
+            .env("UV_DEFAULT_INDEX", &pypi_mirror);
+    }
+
+    Ok(command)
+}
+
 fn build_python_command(state: &State, args: &[String]) -> Result<Command> {
     let python_exe = if cfg!(target_os = "windows") {
         let show_console = std::env::var("ANKI_CONSOLE").is_ok();
         if show_console {
-            state.uv_install_root.join(".venv/Scripts/python.exe")
+            state.venv_folder.join("Scripts/python.exe")
         } else {
-            state.uv_install_root.join(".venv/Scripts/pythonw.exe")
+            state.venv_folder.join("Scripts/pythonw.exe")
         }
     } else {
-        state.uv_install_root.join(".venv/bin/python")
+        state.venv_folder.join("bin/python")
     };
 
     let mut cmd = Command::new(&python_exe);
@@ -892,10 +1006,75 @@ fn build_python_command(state: &State, args: &[String]) -> Result<Command> {
     // Set UV and Python paths for the Python code
     cmd.env("ANKI_LAUNCHER_UV", state.uv_path.utf8()?.as_str());
     cmd.env("UV_PROJECT", state.uv_install_root.utf8()?.as_str());
+    cmd.env_remove("SSLKEYLOGFILE");
 
     Ok(cmd)
 }
 
+fn is_mirror_enabled(state: &State) -> bool {
+    state.mirror_path.exists()
+}
+
+fn get_mirror_urls(state: &State) -> Result<Option<(String, String)>> {
+    if !state.mirror_path.exists() {
+        return Ok(None);
+    }
+
+    let content = read_file(&state.mirror_path)?;
+    let content_str = String::from_utf8(content).context("Invalid UTF-8 in mirror file")?;
+
+    let lines: Vec<&str> = content_str.lines().collect();
+    if lines.len() >= 2 {
+        Ok(Some((
+            lines[0].trim().to_string(),
+            lines[1].trim().to_string(),
+        )))
+    } else {
+        Ok(None)
+    }
+}
+
+fn show_mirror_submenu(state: &State) -> Result<()> {
+    loop {
+        println!("Download mirror options:");
+        println!("1) No mirror");
+        println!("2) China");
+        print!("> ");
+        let _ = stdout().flush();
+
+        let mut input = String::new();
+        let _ = stdin().read_line(&mut input);
+        let input = input.trim();
+
+        match input {
+            "1" => {
+                // Remove mirror file
+                if state.mirror_path.exists() {
+                    let _ = remove_file(&state.mirror_path);
+                }
+                println!("Mirror disabled.");
+                break;
+            }
+            "2" => {
+                // Write China mirror URLs
+                let china_mirrors = "https://registry.npmmirror.com/-/binary/python-build-standalone/\nhttps://mirrors.tuna.tsinghua.edu.cn/pypi/web/simple/";
+                write_file(&state.mirror_path, china_mirrors)?;
+                println!("China mirror enabled.");
+                break;
+            }
+            "" => {
+                // Empty input - return to main menu
+                break;
+            }
+            _ => {
+                println!("Invalid input. Please try again.");
+                continue;
+            }
+        }
+    }
+    Ok(())
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
