@@ -96,6 +96,7 @@ pub struct Card {
     pub(crate) memory_state: Option<FsrsMemoryState>,
     pub(crate) desired_retention: Option<f32>,
     pub(crate) decay: Option<f32>,
+    pub(crate) last_review_time: Option<TimestampSecs>,
     /// JSON object or empty; exposed through the reviewer for persisting custom
     /// state
     pub(crate) custom_data: String,
@@ -147,6 +148,7 @@ impl Default for Card {
             memory_state: None,
             desired_retention: None,
             decay: None,
+            last_review_time: None,
             custom_data: String::new(),
         }
     }
