@@ -3,6 +3,7 @@
 
 use std::sync::LazyLock;
 
+use anki_proto::search::search_node::FieldSearchMode as FieldSearchModeProto;
 use nom::branch::alt;
 use nom::bytes::complete::escaped;
 use nom::bytes::complete::is_not;
@@ -27,7 +28,6 @@ use crate::error::ParseError;
 use crate::error::Result;
 use crate::error::SearchErrorKind as FailKind;
 use crate::prelude::*;
-
 type IResult<'a, O> = std::result::Result<(&'a str, O), nom::Err<ParseError<'a>>>;
 type ParseResult<'a, O> = std::result::Result<O, nom::Err<ParseError<'a>>>;
 
@@ -48,6 +48,23 @@ pub enum Node {
     Search(SearchNode),
 }
 
+#[derive(Copy, Debug, PartialEq, Eq, Clone)]
+pub enum FieldSearchMode {
+    Normal,
+    Regex,
+    NoCombining,
+}
+
+impl From<FieldSearchModeProto> for FieldSearchMode {
+    fn from(mode: FieldSearchModeProto) -> Self {
+        match mode {
+            FieldSearchModeProto::Normal => Self::Normal,
+            FieldSearchModeProto::Regex => Self::Regex,
+            FieldSearchModeProto::Nocombining => Self::NoCombining,
+        }
+    }
+}
+
 #[derive(Debug, PartialEq, Clone)]
 pub enum SearchNode {
     // text without a colon
@@ -56,7 +73,7 @@ pub enum SearchNode {
     SingleField {
         field: String,
         text: String,
-        is_re: bool,
+        mode: FieldSearchMode,
     },
     AddedInDays(u32),
     EditedInDays(u32),
@@ -77,7 +94,7 @@ pub enum SearchNode {
     },
     Tag {
         tag: String,
-        is_re: bool,
+        mode: FieldSearchMode,
     },
     Duplicates {
         notetype_id: NotetypeId,
@@ -158,7 +175,7 @@ pub fn parse(input: &str) -> Result<Vec<Node>> {
 
 /// Zero or more nodes inside brackets, eg 'one OR two -three'.
 /// Empty vec must be handled by caller.
-fn group_inner(input: &str) -> IResult<Vec<Node>> {
+fn group_inner(input: &str) -> IResult<'_, Vec<Node>> {
     let mut remaining = input;
     let mut nodes = vec![];
 
@@ -203,16 +220,16 @@ fn group_inner(input: &str) -> IResult<Vec<Node>> {
     Ok((remaining, nodes))
 }
 
-fn whitespace0(s: &str) -> IResult<Vec<char>> {
+fn whitespace0(s: &str) -> IResult<'_, Vec<char>> {
     many0(one_of(" \u{3000}")).parse(s)
 }
 
 /// Optional leading space, then a (negated) group or text
-fn node(s: &str) -> IResult<Node> {
+fn node(s: &str) -> IResult<'_, Node> {
     preceded(whitespace0, alt((negated_node, group, text))).parse(s)
 }
 
-fn negated_node(s: &str) -> IResult<Node> {
+fn negated_node(s: &str) -> IResult<'_, Node> {
     map(preceded(char('-'), alt((group, text))), |node| {
         Node::Not(Box::new(node))
     })
@@ -220,7 +237,7 @@ fn negated_node(s: &str) -> IResult<Node> {
 }
 
 /// One or more nodes surrounded by brackets, eg (one OR two)
-fn group(s: &str) -> IResult<Node> {
+fn group(s: &str) -> IResult<'_, Node> {
     let (opened, _) = char('(')(s)?;
     let (tail, inner) = group_inner(opened)?;
     if let Some(remaining) = tail.strip_prefix(')') {
@@ -235,18 +252,18 @@ fn group(s: &str) -> IResult<Node> {
 }
 
 /// Either quoted or unquoted text
-fn text(s: &str) -> IResult<Node> {
+fn text(s: &str) -> IResult<'_, Node> {
     alt((quoted_term, partially_quoted_term, unquoted_term)).parse(s)
 }
 
 /// Quoted text, including the outer double quotes.
-fn quoted_term(s: &str) -> IResult<Node> {
+fn quoted_term(s: &str) -> IResult<'_, Node> {
     let (remaining, term) = quoted_term_str(s)?;
     Ok((remaining, Node::Search(search_node_for_text(term)?)))
 }
 
 /// eg deck:"foo bar" - quotes must come after the :
-fn partially_quoted_term(s: &str) -> IResult<Node> {
+fn partially_quoted_term(s: &str) -> IResult<'_, Node> {
     let (remaining, (key, val)) = separated_pair(
         escaped(is_not("\"(): \u{3000}\\"), '\\', none_of(" \u{3000}")),
         char(':'),
@@ -260,7 +277,7 @@ fn partially_quoted_term(s: &str) -> IResult<Node> {
 }
 
 /// Unquoted text, terminated by whitespace or unescaped ", ( or )
-fn unquoted_term(s: &str) -> IResult<Node> {
+fn unquoted_term(s: &str) -> IResult<'_, Node> {
     match escaped(is_not("\"() \u{3000}\\"), '\\', none_of(" \u{3000}"))(s) {
         Ok((tail, term)) => {
             if term.is_empty() {
@@ -297,7 +314,7 @@ fn unquoted_term(s: &str) -> IResult<Node> {
 }
 
 /// Non-empty string delimited by unescaped double quotes.
-fn quoted_term_str(s: &str) -> IResult<&str> {
+fn quoted_term_str(s: &str) -> IResult<'_, &str> {
     let (opened, _) = char('"')(s)?;
     if let Ok((tail, inner)) =
         escaped::<_, ParseError, _, _>(is_not(r#""\"#), '\\', anychar).parse(opened)
@@ -321,7 +338,7 @@ fn quoted_term_str(s: &str) -> IResult<&str> {
 
 /// Determine if text is a qualified search, and handle escaped chars.
 /// Expect well-formed input: unempty and no trailing \.
-fn search_node_for_text(s: &str) -> ParseResult<SearchNode> {
+fn search_node_for_text(s: &str) -> ParseResult<'_, SearchNode> {
     // leading : is only possible error for well-formed input
     let (tail, head) = verify(escaped(is_not(r":\"), '\\', anychar), |t: &str| {
         !t.is_empty()
@@ -369,21 +386,21 @@ fn search_node_for_text_with_argument<'a>(
     })
 }
 
-fn parse_tag(s: &str) -> ParseResult<SearchNode> {
+fn parse_tag(s: &str) -> ParseResult<'_, SearchNode> {
     Ok(if let Some(re) = s.strip_prefix("re:") {
         SearchNode::Tag {
             tag: unescape_quotes(re),
-            is_re: true,
+            mode: FieldSearchMode::Regex,
         }
     } else {
         SearchNode::Tag {
             tag: unescape(s)?,
-            is_re: false,
+            mode: FieldSearchMode::Normal,
         }
     })
 }
 
-fn parse_template(s: &str) -> ParseResult<SearchNode> {
+fn parse_template(s: &str) -> ParseResult<'_, SearchNode> {
     Ok(SearchNode::CardTemplate(match s.parse::<u16>() {
         Ok(n) => TemplateKind::Ordinal(n.max(1) - 1),
         Err(_) => TemplateKind::Name(unescape(s)?),
@@ -391,7 +408,7 @@ fn parse_template(s: &str) -> ParseResult<SearchNode> {
 }
 
 /// flag:0-7
-fn parse_flag(s: &str) -> ParseResult<SearchNode> {
+fn parse_flag(s: &str) -> ParseResult<'_, SearchNode> {
     if let Ok(flag) = s.parse::<u8>() {
         if flag > 7 {
             Err(parse_failure(s, FailKind::InvalidFlag))
@@ -404,7 +421,7 @@ fn parse_flag(s: &str) -> ParseResult<SearchNode> {
 }
 
 /// eg resched:3
-fn parse_resched(s: &str) -> ParseResult<SearchNode> {
+fn parse_resched(s: &str) -> ParseResult<'_, SearchNode> {
     parse_u32(s, "resched:").map(|days| SearchNode::Rated {
         days,
         ease: RatingKind::ManualReschedule,
@@ -412,7 +429,7 @@ fn parse_resched(s: &str) -> ParseResult<SearchNode> {
 }
 
 /// eg prop:ivl>3, prop:ease!=2.5
-fn parse_prop(prop_clause: &str) -> ParseResult<SearchNode> {
+fn parse_prop(prop_clause: &str) -> ParseResult<'_, SearchNode> {
     let (tail, prop) = alt((
         tag("ivl"),
         tag("due"),
@@ -580,23 +597,23 @@ fn parse_prop_rated<'a>(num: &str, context: &'a str) -> ParseResult<'a, Property
 }
 
 /// eg added:1
-fn parse_added(s: &str) -> ParseResult<SearchNode> {
+fn parse_added(s: &str) -> ParseResult<'_, SearchNode> {
     parse_u32(s, "added:").map(|n| SearchNode::AddedInDays(n.max(1)))
 }
 
 /// eg edited:1
-fn parse_edited(s: &str) -> ParseResult<SearchNode> {
+fn parse_edited(s: &str) -> ParseResult<'_, SearchNode> {
     parse_u32(s, "edited:").map(|n| SearchNode::EditedInDays(n.max(1)))
 }
 
 /// eg introduced:1
-fn parse_introduced(s: &str) -> ParseResult<SearchNode> {
+fn parse_introduced(s: &str) -> ParseResult<'_, SearchNode> {
     parse_u32(s, "introduced:").map(|n| SearchNode::IntroducedInDays(n.max(1)))
 }
 
 /// eg rated:3 or rated:10:2
 /// second arg must be between 1-4
-fn parse_rated(s: &str) -> ParseResult<SearchNode> {
+fn parse_rated(s: &str) -> ParseResult<'_, SearchNode> {
     let mut it = s.splitn(2, ':');
     let days = parse_u32(it.next().unwrap(), "rated:")?.max(1);
     let button = parse_answer_button(it.next(), s)?;
@@ -604,7 +621,7 @@ fn parse_rated(s: &str) -> ParseResult<SearchNode> {
 }
 
 /// eg is:due
-fn parse_state(s: &str) -> ParseResult<SearchNode> {
+fn parse_state(s: &str) -> ParseResult<'_, SearchNode> {
     use StateKind::*;
     Ok(SearchNode::State(match s {
         "new" => New,
@@ -624,7 +641,7 @@ fn parse_state(s: &str) -> ParseResult<SearchNode> {
     }))
 }
 
-fn parse_mid(s: &str) -> ParseResult<SearchNode> {
+fn parse_mid(s: &str) -> ParseResult<'_, SearchNode> {
     parse_i64(s, "mid:").map(|n| SearchNode::NotetypeId(n.into()))
 }
 
@@ -646,7 +663,7 @@ fn check_id_list<'a>(s: &'a str, context: &str) -> ParseResult<'a, &'a str> {
 }
 
 /// eg dupe:1231,hello
-fn parse_dupe(s: &str) -> ParseResult<SearchNode> {
+fn parse_dupe(s: &str) -> ParseResult<'_, SearchNode> {
     let mut it = s.splitn(2, ',');
     let ntid = parse_i64(it.next().unwrap(), s)?;
     if let Some(text) = it.next() {
@@ -670,13 +687,19 @@ fn parse_single_field<'a>(key: &'a str, val: &'a str) -> ParseResult<'a, SearchN
         SearchNode::SingleField {
             field: unescape(key)?,
             text: unescape_quotes(stripped),
-            is_re: true,
+            mode: FieldSearchMode::Regex,
+        }
+    } else if let Some(stripped) = val.strip_prefix("nc:") {
+        SearchNode::SingleField {
+            field: unescape(key)?,
+            text: unescape_quotes(stripped),
+            mode: FieldSearchMode::NoCombining,
         }
     } else {
         SearchNode::SingleField {
             field: unescape(key)?,
             text: unescape(val)?,
-            is_re: false,
+            mode: FieldSearchMode::Normal,
         }
     })
 }
@@ -700,7 +723,7 @@ fn unescape_quotes_and_backslashes(s: &str) -> String {
 }
 
 /// Unescape chars with special meaning to the parser.
-fn unescape(txt: &str) -> ParseResult<String> {
+fn unescape(txt: &str) -> ParseResult<'_, String> {
     if let Some(seq) = invalid_escape_sequence(txt) {
         Err(parse_failure(
             txt,
@@ -806,7 +829,7 @@ mod test {
                     Search(SingleField {
                         field: "foo".into(),
                         text: "bar baz".into(),
-                        is_re: false,
+                        mode: FieldSearchMode::Normal,
                     })
                 ]))),
                 Or,
@@ -819,7 +842,16 @@ mod test {
             vec![Search(SingleField {
                 field: "foo".into(),
                 text: "bar".into(),
-                is_re: true
+                mode: FieldSearchMode::Regex,
+            })]
+        );
+
+        assert_eq!(
+            parse("foo:nc:bar")?,
+            vec![Search(SingleField {
+                field: "foo".into(),
+                text: "bar".into(),
+                mode: FieldSearchMode::NoCombining,
             })]
         );
 
@@ -829,7 +861,7 @@ mod test {
             vec![Search(SingleField {
                 field: "field".into(),
                 text: "va\"lue".into(),
-                is_re: false
+                mode: FieldSearchMode::Normal,
             })]
         );
         assert_eq!(parse(r#""field:va\"lue""#)?, parse(r#"field:"va\"lue""#)?,);
@@ -906,14 +938,14 @@ mod test {
             parse("tag:hard")?,
             vec![Search(Tag {
                 tag: "hard".into(),
-                is_re: false
+                mode: FieldSearchMode::Normal
             })]
         );
         assert_eq!(
             parse(r"tag:re:\\")?,
             vec![Search(Tag {
                 tag: r"\\".into(),
-                is_re: true
+                mode: FieldSearchMode::Regex
             })]
         );
         assert_eq!(
