@@ -310,14 +310,14 @@ fn add_extract_fsrs_variable(db: &Connection) -> rusqlite::Result<()> {
 }
 
 /// eg. extract_fsrs_retrievability(card.data, card.due, card.ivl,
-/// timing.days_elapsed, timing.next_day_at) -> float | null
+/// timing.days_elapsed, timing.next_day_at, timing.now) -> float | null
 fn add_extract_fsrs_retrievability(db: &Connection) -> rusqlite::Result<()> {
     db.create_scalar_function(
         "extract_fsrs_retrievability",
-        5,
+        6,
         FunctionFlags::SQLITE_DETERMINISTIC,
         move |ctx| {
-            assert_eq!(ctx.len(), 5, "called with unexpected number of arguments");
+            assert_eq!(ctx.len(), 6, "called with unexpected number of arguments");
             let Ok(card_data) = ctx.get_raw(0).as_str() else {
                 return Ok(None);
             };
@@ -328,18 +328,18 @@ fn add_extract_fsrs_retrievability(db: &Connection) -> rusqlite::Result<()> {
             let Ok(due) = ctx.get_raw(1).as_i64() else {
                 return Ok(None);
             };
-            let days_elapsed = if let Some(last_review_time) = card_data.last_review_time {
-                // Use last_review_time to calculate days_elapsed
-                let Ok(next_day_at) = ctx.get_raw(4).as_i64() else {
-                    return Ok(None);
-                };
-                (next_day_at as u32).saturating_sub(last_review_time.0 as u32) / 86_400
+            let Ok(now) = ctx.get_raw(5).as_i64() else {
+                return Ok(None);
+            };
+            let seconds_elapsed = if let Some(last_review_time) = card_data.last_review_time {
+                now.saturating_sub(last_review_time.0) as u32
             } else if due > 365_000 {
                 // (re)learning card in seconds
-                let Ok(next_day_at) = ctx.get_raw(4).as_i64() else {
+                let Ok(ivl) = ctx.get_raw(2).as_i64() else {
                     return Ok(None);
                 };
-                (next_day_at as u32).saturating_sub(due as u32) / 86_400
+                let last_review_time = due.saturating_sub(ivl);
+                now.saturating_sub(last_review_time) as u32
             } else {
                 let Ok(ivl) = ctx.get_raw(2).as_i64() else {
                     return Ok(None);
@@ -348,29 +348,32 @@ fn add_extract_fsrs_retrievability(db: &Connection) -> rusqlite::Result<()> {
                     return Ok(None);
                 };
                 let review_day = due.saturating_sub(ivl);
-                (days_elapsed as u32).saturating_sub(review_day as u32)
+                days_elapsed.saturating_sub(review_day) as u32 * 86_400
             };
             let decay = card_data.decay.unwrap_or(FSRS5_DEFAULT_DECAY);
-            Ok(card_data.memory_state().map(|state| {
-                FSRS::new(None)
-                    .unwrap()
-                    .current_retrievability(state.into(), days_elapsed, decay)
-            }))
+            let retrievability = card_data.memory_state().map(|state| {
+                FSRS::new(None).unwrap().current_retrievability_seconds(
+                    state.into(),
+                    seconds_elapsed,
+                    decay,
+                )
+            });
+            Ok(retrievability)
         },
     )
 }
 
 /// eg. extract_fsrs_relative_retrievability(card.data, card.due,
-/// timing.days_elapsed, card.ivl, timing.next_day_at) -> float | null. The
-/// higher the number, the higher the card's retrievability relative to the
-/// configured desired retention.
+/// timing.days_elapsed, card.ivl, timing.next_day_at, timing.now) -> float |
+/// null. The higher the number, the higher the card's retrievability relative
+/// to the configured desired retention.
 fn add_extract_fsrs_relative_retrievability(db: &Connection) -> rusqlite::Result<()> {
     db.create_scalar_function(
         "extract_fsrs_relative_retrievability",
-        5,
+        6,
         FunctionFlags::SQLITE_DETERMINISTIC,
         move |ctx| {
-            assert_eq!(ctx.len(), 5, "called with unexpected number of arguments");
+            assert_eq!(ctx.len(), 6, "called with unexpected number of arguments");
 
             let Ok(due) = ctx.get_raw(1).as_i64() else {
                 return Ok(None);
@@ -381,6 +384,9 @@ fn add_extract_fsrs_relative_retrievability(db: &Connection) -> rusqlite::Result
             let Ok(next_day_at) = ctx.get_raw(4).as_i64() else {
                 return Ok(None);
             };
+            let Ok(now) = ctx.get_raw(5).as_i64() else {
+                return Ok(None);
+            };
             let days_elapsed = if due > 365_000 {
                 // (re)learning
                 (next_day_at as u32).saturating_sub(due as u32) / 86_400
@@ -402,17 +408,30 @@ fn add_extract_fsrs_relative_retrievability(db: &Connection) -> rusqlite::Result
                         desired_retrievability = desired_retrievability.max(0.0001);
                         let decay = card_data.decay.unwrap_or(FSRS5_DEFAULT_DECAY);
 
-                        let days_elapsed = if let Some(last_review_time) =
-                            card_data.last_review_time
-                        {
-                            TimestampSecs(next_day_at).elapsed_days_since(last_review_time) as u32
-                        } else {
-                            days_elapsed
-                        };
+                        let seconds_elapsed =
+                            if let Some(last_review_time) = card_data.last_review_time {
+                                now.saturating_sub(last_review_time.0) as u32
+                            } else if due > 365_000 {
+                                // (re)learning card in seconds
+                                let Ok(ivl) = ctx.get_raw(2).as_i64() else {
+                                    return Ok(None);
+                                };
+                                let last_review_time = due.saturating_sub(ivl);
+                                now.saturating_sub(last_review_time) as u32
+                            } else {
+                                let Ok(ivl) = ctx.get_raw(2).as_i64() else {
+                                    return Ok(None);
+                                };
+                                let Ok(days_elapsed) = ctx.get_raw(3).as_i64() else {
+                                    return Ok(None);
+                                };
+                                let review_day = due.saturating_sub(ivl);
+                                days_elapsed.saturating_sub(review_day) as u32 * 86_400
+                            };
 
                         let current_retrievability = FSRS::new(None)
                             .unwrap()
-                            .current_retrievability(state.into(), days_elapsed, decay)
+                            .current_retrievability_seconds(state.into(), seconds_elapsed, decay)
                             .max(0.0001);
 
                         return Ok(Some(
